pub struct SecretString { /* private fields */ }Expand description
Redacted secret wrapper for runtime and connector configuration.
Implementations
Sourceimpl SecretString
impl SecretString
Sourcepub fn from_provider(
provider_name: impl Into<String>,
reference: impl Into<String>,
provider: Arc<dyn SecretProvider>,
) -> Self
pub fn from_provider( provider_name: impl Into<String>, reference: impl Into<String>, provider: Arc<dyn SecretProvider>, ) -> Self
Resolve a secret from an external provider at connect time.
Sourcepub fn from_callback(
label: impl Into<String>,
callback: impl Fn() -> Result<String> + Send + Sync + 'static,
) -> Self
pub fn from_callback( label: impl Into<String>, callback: impl Fn() -> Result<String> + Send + Sync + 'static, ) -> Self
Resolve a secret through a callback at connect time.
Sourcepub fn expose_secret(&self) -> Result<&str>
pub fn expose_secret(&self) -> Result<&str>
Return the inline secret value.
Deferred secrets must be resolved with resolve.
Sourcepub fn into_inner(self) -> Result<String>
pub fn into_inner(self) -> Result<String>
Consume the wrapper and return the inline secret.